<?php

namespace NF\Discord\Admin\Controller;

use NF\Discord\Helper;
use XF\Admin\Controller\AbstractController;

use NF\Discord\Api;
use XF\Legacy\ControllerResponse\Redirect;
use XF\Mvc\ParameterBag;

class Discord extends AbstractController
{
	public function actionIndex()
	{
		return $this->view(
			'NF\Discord:Index',
			'nf_discord_index'
		);
	}

	public function actionInviteBot()
	{
		$api = Api::factory();

		$viewParams = [
			'link' => $api->getBotAuthorizeLink(),
		];

		return $this->view(
			'NF\Discord:Discord\InviteBot',
			'nf_discord_invite_bot',
			$viewParams
		);
	}

	public function actionGroupsUser()
	{
		$viewParams = [
			'userGroups' => $this->finder('XF:UserGroup')->fetch(),
		];

		return $this->view(
			'NF\Discord:UserGroups\List',
			'nixfifty_discord_user_groups_list',
			$viewParams
		);
	}

	public function actionGroupsUserEdit(ParameterBag $params)
	{
		$userGroup = $this->assertRecordExists('XF:UserGroup', $params->user_group_id);
		$api = Api::factory();

		$viewParams = [
			'usergroup' => $userGroup,

			'roles' => $api->getRoles(),
			'selRoleIds' => $userGroup->nfd_server_group_ids,
		];

		return $this->view(
			'NF\Discord:UserGroup\Edit',
			'nf_discord_user_group_edit',
			$viewParams
		);
	}

	public function actionGroupsUserSave(ParameterBag $params)
	{
		$this->assertPostOnly();

		$userGroupId = $params->user_group_id;
		$userGroup = $this->assertRecordExists('XF:UserGroup', $params->user_group_id);

		$userGroup->fastUpdate('nfd_server_group_ids', $this->filter('roles', 'array-str'));

		\XF::runOnce('nfd-group-sync', function () use ($userGroupId)
		{
			\XF::app()->jobManager()->enqueueUnique('nfd-group-sync', 'NF\Discord:GroupSync', ['user_group_id' => $userGroupId]);
		});

		return $this->redirect(
			$this->buildLink('discord/groups/user') . $this->buildLinkHash($userGroupId)
		);
	}
}