<?php

namespace NF\Discord\Admin\Controller;

use NF\Discord\Helper;
use XF\Admin\Controller\AbstractController;
use XF\Mvc\ParameterBag;

use NF\Discord\Api;

class Role extends AbstractController
{
	public function actionIndex(ParameterBag $params)
	{
		$api = Api::factory();

		$viewParams = [
			'roles' => $api->getRoles(),
		];

		return $this->view('NF\Discord:Role\List', 'nf_discord_role_list', $viewParams);
	}

	public function actionEdit(ParameterBag $params)
	{
		$api = Api::factory();
		$helper = Helper::factory();
		$role = $api->getRole($params['id']);
		$permissionsConstants = $helper->getPermissionConstants();
		$permissions = [];

		foreach ($permissionsConstants as $key => $value)
		{
			$permissions[$key] = ($role['permissions'] & $value) != 0;
		}
		$viewParams = [
			'role' => $role,
			'permissions' => $permissions,
		];

		return $this->view('NF\Discord:Role\Edit', 'nf_discord_role_edit', $viewParams);
	}

	public function actionDelete(ParameterBag $params)
	{
		$api = Api::factory();
		$role = $api->getRole($params['id']);

		if (!$role)
		{
			return $this->error($this->notFound(\XF::phrase('nf_discord_requested_role_not_found')));
		}

		if ($this->isPost())
		{
			$api->deleteRole($role['id']);
			return $this->redirect($this->buildLink('discord/roles'));
		}
		else
		{
			$viewParams = [
				'role' => $role,
			];
			return $this->view('NF\Discord:Role\Delete', 'nf_discord_role_delete', $viewParams);
		}
	}

	public function actionSave(ParameterBag $params)
	{
		$api = Api::factory();
		$helper = Helper::factory();
		$boolPerms = $this->filter(Api::getRolePermissionInputFilters());
		$permissions = $helper->forgePermissions($boolPerms);
		$roleData = $this->filter([
			'name' => 'str',
			'position' => 'int',
			'hoist' => 'bool',
			'mentionable' => 'bool',
		]);
		$roleData['id'] = $params->id;
		$roleData['permissions'] = $permissions;
		if (!empty($roleData['id']))
		{
			$api->updateRole($roleData['id'], $roleData);

			return $this->redirect($this->buildLink('discord/roles', $roleData));
		}
		else
		{
			$api->createRole($roleData);
			return $this->redirect($this->redirect($this->buildLink('discord/roles')));
		}
	}
}