<?php

namespace NF\Discord\XF\Entity;

use NF\Discord\Api;
use XF\Mvc\Entity\Entity;
use XF\Mvc\Entity\Structure;

/**
 * Extends \XF\Entity\ReportComment
 */
class ReportComment extends XFCP_ReportComment
{
	/**
	 * @param $noticeType
	 *
	 * @throws \XF\PrintableException
	 */
	public function nfNotifyDiscord($noticeType)
	{
		/** @var \SV\ReportCentreEssentials\XF\Entity\Report $report */
		$report = $this->Report;
		if (empty($report->ReportQueue))
		{
			return;
		}

		/** @var \NF\Discord\SV\ReportCentreEssentials\Entity\ReportQueue $reportQueue */
		$reportQueue = $report->ReportQueue;
		if (empty($reportQueue->nf_discord_channel_id))
		{
			return;
		}

		$app = $this->app();
		$router = \XF::app()->router('public');
		$url = $router->buildLink('full:reports', $report) . '#report-comment-' . $this->report_comment_id;
		$phrase = \XF::phrase('nfDiscord_notice.' . $noticeType, [
			'name' => $this->username,
			'contentName' => $report->username,
			'contentTitle' => $report->title,
			'reportQueue' => $reportQueue->queue_name,
			'openReports' => $reportQueue->stats['open'],
			'url' => $url,
		]);

		$snippet = $app->stringFormatter()->stripBbCode($this->message, [
			'stripQuote' => false,
		]);
		$snippet = $app->stringFormatter()->wholeWordTrim($snippet, 500);

		$api = Api::factory(false);
		if ($api)
		{
			$api->createMessage($reportQueue->nf_discord_channel_id, $phrase->render('raw'), [
				'author' => [
					'name' => $this->username,
					'url' => $router->buildLink('full:members', $this->User),
					'icon_url' => $this->User->getAvatarUrl('s', null, true)
				],
				'footer' => [
					'text' => $reportQueue->queue_name,
				],
				'title' => $report->title,
				'url' => $url,
				'description' => $snippet,
				'timestamp' => date('c', $report->first_report_date),
			]);
		}
	}

}