<?php

namespace NF\Discord\XF\Service\Conversation;

use NF\Discord\Api;

/**
 * Extends \XF\Service\Conversation\Notifier
 */
class Notifier extends XFCP_Notifier
{
	protected function _sendNotifications($actionType, array $notifyUsers, \XF\Entity\ConversationMessage $message = null, \XF\Entity\User $sender = null)
	{
		$parent = parent::_sendNotifications($actionType, $notifyUsers, $message, $sender);

		/** @var \XF\Entity\User $user */
		foreach ($notifyUsers AS $user)
		{
			if ($user->user_state == 'valid'
				&& !$user->is_banned
				&& $message->User != $user
				&& $discord = $user->ConnectedAccounts['nfDiscord']
			)
			{
				$router = \XF::app()->router('public');
				$formatter = $this->app->stringFormatter();
				$snippet = $formatter->snippetString($message->message, 250, [
					'stripBbCode' => true,
					'stripQuote' => true,
				]);

				$conversationTitle = strip_tags($message->Conversation->title);
				$conversationTitle = html_entity_decode($conversationTitle);

				$api = Api::factory(false);
				if ($api)
				{
					$dm = $api->createDM($discord['provider_key']);
					$api->createMessage($dm['id'], \XF::phrase('nf_discord_conversation_reply_subject', ['title' => $message->Conversation->title]), [
						'author' => [
							'name' => $message->username,
							'url' => $router->buildLink('full:members', $message->User),
							'icon_url' => $message->User->getAvatarUrl('s', null, true)
						],
						'footer' => [
							'text' => \XF::options()->boardTitle,
						],
						'url' => \XF::app()->router('public')->buildLink('full:conversations/unread', $message->Conversation),
						'title' => $conversationTitle,
						'description' => $snippet,
						'timestamp' => date('c', $message->message_date),
					]);
				}
			}
		}

		return $parent;
	}
}